@@ -202,9 +202,10 @@ class LibSwitchStage(Stage):
         return False
 
     def find_new_stages(self, kwargs):
-
+        stages_searched = []
         for filter_tuple in self.stages_filter:
             label, text, stages_label = filter_tuple
+            stages_searched.append(stages_label)
             #
             if label == "*" and text is True:
                 return stages_label
@@ -225,7 +226,7 @@ class LibSwitchStage(Stage):
             if pass_token:
                 return stages_label
 
-        raise RuntimeError("Not Found Path")
+        raise RuntimeError(f"Not Found Path: {stages_searched}")
 
     def is_fit_needs_n_gen_entity(self, kwargs) -> (bool, dict):
         raise RuntimeError
